# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: packet_storm.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='packet_storm.proto',
  package='strobesbufs.scrappers.packet_storm',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12packet_storm.proto\x12\"strobesbufs.scrappers.packet_storm\"I\n\x07\x45xploit\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04link\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\"i\n\x0bPacketStorm\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x0b\n\x03\x63ve\x18\x02 \x01(\t\x12=\n\x08\x65xploits\x18\x03 \x03(\x0b\x32+.strobesbufs.scrappers.packet_storm.Exploit\"O\n\x06Result\x12\x45\n\x0cpacket_storm\x18\x01 \x03(\x0b\x32/.strobesbufs.scrappers.packet_storm.PacketStormb\x06proto3'
)




_EXPLOIT = _descriptor.Descriptor(
  name='Exploit',
  full_name='strobesbufs.scrappers.packet_storm.Exploit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='strobesbufs.scrappers.packet_storm.Exploit.description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='strobesbufs.scrappers.packet_storm.Exploit.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link', full_name='strobesbufs.scrappers.packet_storm.Exploit.link', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='strobesbufs.scrappers.packet_storm.Exploit.tags', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=131,
)


_PACKETSTORM = _descriptor.Descriptor(
  name='PacketStorm',
  full_name='strobesbufs.scrappers.packet_storm.PacketStorm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='strobesbufs.scrappers.packet_storm.PacketStorm.source', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cve', full_name='strobesbufs.scrappers.packet_storm.PacketStorm.cve', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exploits', full_name='strobesbufs.scrappers.packet_storm.PacketStorm.exploits', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133,
  serialized_end=238,
)


_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='strobesbufs.scrappers.packet_storm.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='packet_storm', full_name='strobesbufs.scrappers.packet_storm.Result.packet_storm', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=240,
  serialized_end=319,
)

_PACKETSTORM.fields_by_name['exploits'].message_type = _EXPLOIT
_RESULT.fields_by_name['packet_storm'].message_type = _PACKETSTORM
DESCRIPTOR.message_types_by_name['Exploit'] = _EXPLOIT
DESCRIPTOR.message_types_by_name['PacketStorm'] = _PACKETSTORM
DESCRIPTOR.message_types_by_name['Result'] = _RESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Exploit = _reflection.GeneratedProtocolMessageType('Exploit', (_message.Message,), {
  'DESCRIPTOR' : _EXPLOIT,
  '__module__' : 'packet_storm_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.packet_storm.Exploit)
  })
_sym_db.RegisterMessage(Exploit)

PacketStorm = _reflection.GeneratedProtocolMessageType('PacketStorm', (_message.Message,), {
  'DESCRIPTOR' : _PACKETSTORM,
  '__module__' : 'packet_storm_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.packet_storm.PacketStorm)
  })
_sym_db.RegisterMessage(PacketStorm)

Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'packet_storm_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.packet_storm.Result)
  })
_sym_db.RegisterMessage(Result)


# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strobesbufs.messier.workflows import services_pb2 as strobesbufs_dot_messier_dot_workflows_dot_services__pb2


class WorkflowServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.WorkflowValidate = channel.unary_unary(
                '/strobesbufs.messier.workflow.services.WorkflowService/WorkflowValidate',
                request_serializer=strobesbufs_dot_messier_dot_workflows_dot_services__pb2.WorkflowValidateRequest.SerializeToString,
                response_deserializer=strobesbufs_dot_messier_dot_workflows_dot_services__pb2.WorkflowValidateResponse.FromString,
                )
        self.WorkflowExecute = channel.unary_unary(
                '/strobesbufs.messier.workflow.services.WorkflowService/WorkflowExecute',
                request_serializer=strobesbufs_dot_messier_dot_workflows_dot_services__pb2.WorkflowExecuteRequest.SerializeToString,
                response_deserializer=strobesbufs_dot_messier_dot_workflows_dot_services__pb2.WorkflowExecuteResponse.FromString,
                )
        self.GetResults = channel.unary_unary(
                '/strobesbufs.messier.workflow.services.WorkflowService/GetResults',
                request_serializer=strobesbufs_dot_messier_dot_workflows_dot_services__pb2.GetResultsRequest.SerializeToString,
                response_deserializer=strobesbufs_dot_messier_dot_workflows_dot_services__pb2.GetResultsResponse.FromString,
                )


class WorkflowServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def WorkflowValidate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WorkflowExecute(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetResults(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WorkflowServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'WorkflowValidate': grpc.unary_unary_rpc_method_handler(
                    servicer.WorkflowValidate,
                    request_deserializer=strobesbufs_dot_messier_dot_workflows_dot_services__pb2.WorkflowValidateRequest.FromString,
                    response_serializer=strobesbufs_dot_messier_dot_workflows_dot_services__pb2.WorkflowValidateResponse.SerializeToString,
            ),
            'WorkflowExecute': grpc.unary_unary_rpc_method_handler(
                    servicer.WorkflowExecute,
                    request_deserializer=strobesbufs_dot_messier_dot_workflows_dot_services__pb2.WorkflowExecuteRequest.FromString,
                    response_serializer=strobesbufs_dot_messier_dot_workflows_dot_services__pb2.WorkflowExecuteResponse.SerializeToString,
            ),
            'GetResults': grpc.unary_unary_rpc_method_handler(
                    servicer.GetResults,
                    request_deserializer=strobesbufs_dot_messier_dot_workflows_dot_services__pb2.GetResultsRequest.FromString,
                    response_serializer=strobesbufs_dot_messier_dot_workflows_dot_services__pb2.GetResultsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strobesbufs.messier.workflow.services.WorkflowService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class WorkflowService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def WorkflowValidate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strobesbufs.messier.workflow.services.WorkflowService/WorkflowValidate',
            strobesbufs_dot_messier_dot_workflows_dot_services__pb2.WorkflowValidateRequest.SerializeToString,
            strobesbufs_dot_messier_dot_workflows_dot_services__pb2.WorkflowValidateResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WorkflowExecute(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strobesbufs.messier.workflow.services.WorkflowService/WorkflowExecute',
            strobesbufs_dot_messier_dot_workflows_dot_services__pb2.WorkflowExecuteRequest.SerializeToString,
            strobesbufs_dot_messier_dot_workflows_dot_services__pb2.WorkflowExecuteResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetResults(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strobesbufs.messier.workflow.services.WorkflowService/GetResults',
            strobesbufs_dot_messier_dot_workflows_dot_services__pb2.GetResultsRequest.SerializeToString,
            strobesbufs_dot_messier_dot_workflows_dot_services__pb2.GetResultsResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strobesbufs/messier/functions/function.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strobesbufs.messier.functions import slack_pb2 as strobesbufs_dot_messier_dot_functions_dot_slack__pb2
from strobesbufs.messier.functions import git_pb2 as strobesbufs_dot_messier_dot_functions_dot_git__pb2
from strobesbufs.messier.functions import svn_pb2 as strobesbufs_dot_messier_dot_functions_dot_svn__pb2
from strobesbufs.messier.functions import docker_pb2 as strobesbufs_dot_messier_dot_functions_dot_docker__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='strobesbufs/messier/functions/function.proto',
  package='strobesbufs.messier.function',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,strobesbufs/messier/functions/function.proto\x12\x1cstrobesbufs.messier.function\x1a)strobesbufs/messier/functions/slack.proto\x1a\'strobesbufs/messier/functions/git.proto\x1a\'strobesbufs/messier/functions/svn.proto\x1a*strobesbufs/messier/functions/docker.proto\"\xe8\x01\n\x08\x46unction\x12\x34\n\x05Slack\x18\x01 \x01(\x0b\x32#.strobesbufs.messier.function.SlackH\x00\x12\x30\n\x03Git\x18\x02 \x01(\x0b\x32!.strobesbufs.messier.function.GitH\x00\x12\x30\n\x03Svn\x18\x03 \x01(\x0b\x32!.strobesbufs.messier.function.SvnH\x00\x12\x36\n\x06\x44ocker\x18\x04 \x01(\x0b\x32$.strobesbufs.messier.function.DockerH\x00\x42\n\n\x08\x66unctionb\x06proto3'
  ,
  dependencies=[strobesbufs_dot_messier_dot_functions_dot_slack__pb2.DESCRIPTOR,strobesbufs_dot_messier_dot_functions_dot_git__pb2.DESCRIPTOR,strobesbufs_dot_messier_dot_functions_dot_svn__pb2.DESCRIPTOR,strobesbufs_dot_messier_dot_functions_dot_docker__pb2.DESCRIPTOR,])




_FUNCTION = _descriptor.Descriptor(
  name='Function',
  full_name='strobesbufs.messier.function.Function',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Slack', full_name='strobesbufs.messier.function.Function.Slack', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Git', full_name='strobesbufs.messier.function.Function.Git', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Svn', full_name='strobesbufs.messier.function.Function.Svn', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Docker', full_name='strobesbufs.messier.function.Function.Docker', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='function', full_name='strobesbufs.messier.function.Function.function',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=248,
  serialized_end=480,
)

_FUNCTION.fields_by_name['Slack'].message_type = strobesbufs_dot_messier_dot_functions_dot_slack__pb2._SLACK
_FUNCTION.fields_by_name['Git'].message_type = strobesbufs_dot_messier_dot_functions_dot_git__pb2._GIT
_FUNCTION.fields_by_name['Svn'].message_type = strobesbufs_dot_messier_dot_functions_dot_svn__pb2._SVN
_FUNCTION.fields_by_name['Docker'].message_type = strobesbufs_dot_messier_dot_functions_dot_docker__pb2._DOCKER
_FUNCTION.oneofs_by_name['function'].fields.append(
  _FUNCTION.fields_by_name['Slack'])
_FUNCTION.fields_by_name['Slack'].containing_oneof = _FUNCTION.oneofs_by_name['function']
_FUNCTION.oneofs_by_name['function'].fields.append(
  _FUNCTION.fields_by_name['Git'])
_FUNCTION.fields_by_name['Git'].containing_oneof = _FUNCTION.oneofs_by_name['function']
_FUNCTION.oneofs_by_name['function'].fields.append(
  _FUNCTION.fields_by_name['Svn'])
_FUNCTION.fields_by_name['Svn'].containing_oneof = _FUNCTION.oneofs_by_name['function']
_FUNCTION.oneofs_by_name['function'].fields.append(
  _FUNCTION.fields_by_name['Docker'])
_FUNCTION.fields_by_name['Docker'].containing_oneof = _FUNCTION.oneofs_by_name['function']
DESCRIPTOR.message_types_by_name['Function'] = _FUNCTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Function = _reflection.GeneratedProtocolMessageType('Function', (_message.Message,), {
  'DESCRIPTOR' : _FUNCTION,
  '__module__' : 'strobesbufs.messier.functions.function_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.messier.function.Function)
  })
_sym_db.RegisterMessage(Function)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xotweet.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='xotweet.proto',
  package='strobesbufs.scrappers.xotweet',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\rxotweet.proto\x12\x1dstrobesbufs.scrappers.xotweet\"\xc2\x01\n\x07XOTweet\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x12\n\ntwitter_id\x18\x03 \x01(\t\x12\x0b\n\x03\x63ve\x18\x04 \x01(\t\x12\x0b\n\x03geo\x18\x05 \x01(\t\x12\x15\n\rretweet_count\x18\x06 \x01(\x02\x12\x16\n\x0e\x66\x61vorite_count\x18\x07 \x01(\x02\x12\x16\n\x0epublished_date\x18\x08 \x01(\t\x12\x0c\n\x04link\x18\t \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\n \x01(\t\"A\n\x06Result\x12\x37\n\x07xotweet\x18\x01 \x03(\x0b\x32&.strobesbufs.scrappers.xotweet.XOTweetb\x06proto3'
)




_XOTWEET = _descriptor.Descriptor(
  name='XOTweet',
  full_name='strobesbufs.scrappers.xotweet.XOTweet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='strobesbufs.scrappers.xotweet.XOTweet.source', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='strobesbufs.scrappers.xotweet.XOTweet.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='twitter_id', full_name='strobesbufs.scrappers.xotweet.XOTweet.twitter_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cve', full_name='strobesbufs.scrappers.xotweet.XOTweet.cve', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo', full_name='strobesbufs.scrappers.xotweet.XOTweet.geo', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retweet_count', full_name='strobesbufs.scrappers.xotweet.XOTweet.retweet_count', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='favorite_count', full_name='strobesbufs.scrappers.xotweet.XOTweet.favorite_count', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='published_date', full_name='strobesbufs.scrappers.xotweet.XOTweet.published_date', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link', full_name='strobesbufs.scrappers.xotweet.XOTweet.link', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='strobesbufs.scrappers.xotweet.XOTweet.description', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=243,
)


_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='strobesbufs.scrappers.xotweet.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='xotweet', full_name='strobesbufs.scrappers.xotweet.Result.xotweet', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=310,
)

_RESULT.fields_by_name['xotweet'].message_type = _XOTWEET
DESCRIPTOR.message_types_by_name['XOTweet'] = _XOTWEET
DESCRIPTOR.message_types_by_name['Result'] = _RESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

XOTweet = _reflection.GeneratedProtocolMessageType('XOTweet', (_message.Message,), {
  'DESCRIPTOR' : _XOTWEET,
  '__module__' : 'xotweet_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.xotweet.XOTweet)
  })
_sym_db.RegisterMessage(XOTweet)

Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'xotweet_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.scrappers.xotweet.Result)
  })
_sym_db.RegisterMessage(Result)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: analyzers.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='analyzers.proto',
  package='strobesbufs.analyzers.analyzer',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0f\x61nalyzers.proto\x12\x1estrobesbufs.analyzers.analyzer\x1a\x1cgoogle/protobuf/struct.proto\"i\n\x08ScanMeta\x12\x10\n\x08\x63ritical\x18\x01 \x01(\x05\x12\x0c\n\x04high\x18\x02 \x01(\x05\x12\x0e\n\x06medium\x18\x03 \x01(\x05\x12\x0b\n\x03low\x18\x04 \x01(\x05\x12\x0c\n\x04info\x18\x05 \x01(\x05\x12\x12\n\ntotal_bugs\x18\x06 \x01(\x05\"n\n\x04SAST\x12\x11\n\tfile_name\x18\x01 \x01(\t\x12\x17\n\x0fvulnerable_code\x18\x02 \x01(\t\x12\x15\n\rstart_line_no\x18\x03 \x01(\t\x12\x13\n\x0b\x65nd_line_no\x18\x04 \x01(\t\x12\x0e\n\x06\x63ommit\x18\x05 \x01(\t\"\xab\x01\n\x04\x44\x41ST\x12\x0b\n\x03uri\x18\x01 \x03(\t\x12\x32\n\x04port\x18\x02 \x01(\x0b\x32$.strobesbufs.analyzers.analyzer.Port\x12\x0e\n\x06method\x18\x03 \x01(\t\x12\r\n\x05param\x18\x04 \x01(\t\x12\x10\n\x08\x65vidence\x18\x05 \x01(\t\x12\x17\n\x0frequest_headers\x18\x06 \x01(\t\x12\x18\n\x10response_headers\x18\x07 \x01(\t\"\x83\x01\n\x07Network\x12\x11\n\tipaddress\x18\x01 \x01(\t\x12\x32\n\x04port\x18\x02 \x01(\x0b\x32$.strobesbufs.analyzers.analyzer.Port\x12\x10\n\x08hostname\x18\x03 \x01(\t\x12\x12\n\nmacaddress\x18\x04 \x01(\t\x12\x0b\n\x03\x63pe\x18\x05 \x01(\t\"]\n\x07Package\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x19\n\x11installed_version\x18\x02 \x01(\t\x12\x19\n\x11\x61\x66\x66\x65\x63ted_versions\x18\x03 \x01(\t\x12\x0e\n\x06\x63ommit\x18\x04 \x01(\t\"p\n\tContainer\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x15\n\rfixed_version\x18\x02 \x01(\t\x12\x19\n\x11installed_version\x18\x03 \x01(\t\x12\x0b\n\x03\x63pe\x18\x04 \x03(\t\x12\x0e\n\x06\x64igest\x18\x05 \x01(\t\"\xcd\x03\n\x03\x41WS\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12\x36\n\x04type\x18\x02 \x01(\x0e\x32(.strobesbufs.analyzers.analyzer.AWS.Type\x12\x10\n\x08\x63\x61tegory\x18\x03 \x01(\t\"\xe6\x02\n\x04Type\x12\x0b\n\x07\x41\x43\x43OUNT\x10\x00\x12\x0f\n\x0b\x41PI_GATEWAY\x10\x01\x12\x17\n\x13\x43\x45RTIFICATE_MANAGER\x10\x02\x12\x12\n\x0e\x43LOUDFORMATION\x10\x03\x12\x0e\n\nCLOUDFRONT\x10\x04\x12\x0e\n\nCLOUDTRAIL\x10\x05\x12\x07\n\x03\x45\x43\x32\x10\x06\x12\x11\n\rSECURITYGROUP\x10\x07\x12\x07\n\x03VPC\x10\x08\x12\x07\n\x03\x45\x43S\x10\t\x12\x07\n\x03\x45KS\x10\n\x12\x11\n\rELASTICSEARCH\x10\x0b\x12\x07\n\x03\x45LB\x10\x0c\x12\x07\n\x03IAM\x10\r\x12\x07\n\x03KMS\x10\x0e\x12\n\n\x06LAMBDA\x10\x0f\x12\x07\n\x03RDS\x10\x10\x12\x0c\n\x08REDSHIFT\x10\x11\x12\x06\n\x02S3\x10\x12\x12\x07\n\x03SNS\x10\x13\x12\x07\n\x03SQS\x10\x14\x12\r\n\tGUARDDUTY\x10\x15\x12\x0b\n\x07ROUTE53\x10\x16\x12\x07\n\x03\x45\x43R\x10\x17\x12\x0b\n\x07GLACIER\x10\x18\x12\x13\n\x0f\x41\x43\x43\x45SS_ANALYZER\x10\x19\x12\n\n\x06OTHERS\x10\x1a\"I\n\x05\x43loud\x12\x0e\n\x06region\x18\x01 \x01(\t\x12\x30\n\x03\x61ws\x18\x02 \x01(\x0b\x32#.strobesbufs.analyzers.analyzer.AWS\"\x81\x02\n\x04Port\x12\x10\n\x08protocol\x18\x01 \x01(\t\x12\x0f\n\x07port_id\x18\x02 \x01(\t\x12\x0f\n\x07service\x18\x03 \x01(\t\x12\x0f\n\x07product\x18\x04 \x01(\t\x12\x39\n\x05state\x18\x05 \x01(\x0e\x32*.strobesbufs.analyzers.analyzer.Port.State\"y\n\x05State\x12\x0e\n\nNOTDEFINED\x10\x00\x12\x08\n\x04OPEN\x10\x01\x12\n\n\x06\x43LOSED\x10\x02\x12\x0c\n\x08\x46ILTERED\x10\x03\x12\x0e\n\nUNFILTERED\x10\x04\x12\x14\n\x10OPEN_OR_FILTERED\x10\x05\x12\x16\n\x12\x43LOSED_OR_FILTERED\x10\x06\"\xa7\x02\n\x05\x41sset\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tipaddress\x18\x02 \x01(\t\x12\n\n\x02os\x18\x03 \x03(\t\x12\x13\n\x0bmac_address\x18\x04 \x01(\t\x12\x10\n\x08hostname\x18\x05 \x01(\t\x12\x0f\n\x07netbios\x18\x06 \x01(\t\x12\x0b\n\x03\x63pe\x18\x07 \x03(\t\x12\x0c\n\x04tags\x18\x08 \x03(\t\x12\x12\n\nrisk_score\x18\t \x01(\t\x12\x33\n\x05ports\x18\n \x03(\x0b\x32$.strobesbufs.analyzers.analyzer.Port\x12:\n\x05state\x18\x0b \x01(\x0e\x32+.strobesbufs.analyzers.analyzer.Asset.State\"\x19\n\x05State\x12\x08\n\x04\x44OWN\x10\x00\x12\x06\n\x02UP\x10\x01\"\x81\x06\n\x03\x42ug\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08severity\x18\x03 \x01(\x05\x12\x0c\n\x04\x43VSS\x18\x04 \x01(\x02\x12\x19\n\x11step_to_reproduce\x18\x05 \x01(\t\x12\x12\n\nmitigation\x18\x06 \x01(\t\x12\x0b\n\x03\x43VE\x18\x07 \x03(\t\x12\x0b\n\x03\x43WE\x18\x08 \x03(\t\x12\x12\n\nreferences\x18\t \x03(\t\x12\x32\n\x04sast\x18\n \x01(\x0b\x32$.strobesbufs.analyzers.analyzer.SAST\x12\x32\n\x04\x64\x61st\x18\x0b \x01(\x0b\x32$.strobesbufs.analyzers.analyzer.DAST\x12\x38\n\x07network\x18\x0c \x01(\x0b\x32\'.strobesbufs.analyzers.analyzer.Network\x12\x34\n\x05\x63loud\x18\r \x01(\x0b\x32%.strobesbufs.analyzers.analyzer.Cloud\x12\x38\n\x07package\x18\x0e \x01(\x0b\x32\'.strobesbufs.analyzers.analyzer.Package\x12<\n\tcontainer\x18\x0f \x01(\x0b\x32).strobesbufs.analyzers.analyzer.Container\x12J\n\x0cscan_details\x18\x10 \x03(\x0b\x32\x34.strobesbufs.analyzers.analyzer.Bug.ScanDetailsEntry\x12\x0c\n\x04tags\x18\x11 \x03(\t\x12+\n\nextra_info\x18\x12 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x18\n\x10vulnerable_since\x18\x13 \x01(\t\x12\x34\n\x05\x61sset\x18\x14 \x01(\x0b\x32%.strobesbufs.analyzers.analyzer.Asset\x1a\x32\n\x10ScanDetailsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9f\x06\n\x06Result\x12;\n\tscan_meta\x18\x01 \x01(\x0b\x32(.strobesbufs.analyzers.analyzer.ScanMeta\x12\x36\n\tbugs_list\x18\x02 \x03(\x0b\x32#.strobesbufs.analyzers.analyzer.Bug\x12:\n\x0b\x61ssets_list\x18\x03 \x03(\x0b\x32%.strobesbufs.analyzers.analyzer.Asset\x12\x41\n\x08\x61nalyzer\x18\x04 \x01(\x0e\x32/.strobesbufs.analyzers.analyzer.Result.Analyzer\x12=\n\x06parser\x18\x05 \x01(\x0e\x32-.strobesbufs.analyzers.analyzer.Result.Parser\x12\x0f\n\x07success\x18\x06 \x01(\x08\"\xb0\x02\n\x08\x41nalyzer\x12\x0e\n\nNOANALYZER\x10\x00\x12\x0c\n\x08SPOTBUGS\x10\x01\x12\x0b\n\x07PROWLER\x10\x02\x12\x07\n\x03ZAP\x10\x03\x12\t\n\x05TRIVY\x10\x04\x12\x0b\n\x07\x41NCHORE\x10\x05\x12\n\n\x06\x42\x41NDIT\x10\x06\x12\x0c\n\x08\x42RAKEMAN\x10\x07\x12\r\n\tNODEJSCAN\x10\x08\x12\t\n\x05PHPCS\x10\t\x12\n\n\x06\x45SLINT\x10\n\x12\r\n\tSCODESCAN\x10\x0b\x12\x0c\n\x08GITLEAKS\x10\x0c\x12\x0f\n\x0b\x43LOUDMAPPER\x10\r\x12\t\n\x05GOSEC\x10\x0e\x12\x0e\n\nFLAWFINDER\x10\x0f\x12\x0e\n\nDEPENDENCY\x10\x10\x12\x08\n\x04NMAP\x10\x11\x12\r\n\tSONARQUBE\x10\x12\x12\r\n\tBURPSUITE\x10\x13\x12\n\n\x06NESSUS\x10\x14\x12\x0b\n\x07NEXPOSE\x10\x15\"\x9d\x01\n\x06Parser\x12\x0c\n\x08NOPARSER\x10\x00\x12\x13\n\x0f\x42URP_XML_PARSER\x10\x01\x12\x15\n\x11QUALYS_XML_PARSER\x10\x02\x12\x15\n\x11NESSUS_XML_PARSER\x10\x03\x12\x16\n\x12NEXPOSE_XML_PARSER\x10\x04\x12\x15\n\x11POSTMAN_CONVERTER\x10\x05\x12\x13\n\x0fNMAP_XML_PARSER\x10\x06\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,])



_AWS_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='strobesbufs.analyzers.analyzer.AWS.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACCOUNT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='API_GATEWAY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_MANAGER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLOUDFORMATION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLOUDFRONT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLOUDTRAIL', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EC2', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECURITYGROUP', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VPC', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ECS', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EKS', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ELASTICSEARCH', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ELB', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IAM', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KMS', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LAMBDA', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RDS', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REDSHIFT', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='S3', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SNS', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SQS', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GUARDDUTY', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROUTE53', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ECR', index=23, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GLACIER', index=24, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACCESS_ANALYZER', index=25, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OTHERS', index=26, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=921,
  serialized_end=1279,
)
_sym_db.RegisterEnumDescriptor(_AWS_TYPE)

_PORT_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='strobesbufs.analyzers.analyzer.Port.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOTDEFINED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPEN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLOSED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FILTERED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNFILTERED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPEN_OR_FILTERED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLOSED_OR_FILTERED', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1493,
  serialized_end=1614,
)
_sym_db.RegisterEnumDescriptor(_PORT_STATE)

_ASSET_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='strobesbufs.analyzers.analyzer.Asset.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1887,
  serialized_end=1912,
)
_sym_db.RegisterEnumDescriptor(_ASSET_STATE)

_RESULT_ANALYZER = _descriptor.EnumDescriptor(
  name='Analyzer',
  full_name='strobesbufs.analyzers.analyzer.Result.Analyzer',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOANALYZER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPOTBUGS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROWLER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ZAP', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRIVY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ANCHORE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BANDIT', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAKEMAN', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NODEJSCAN', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PHPCS', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ESLINT', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCODESCAN', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GITLEAKS', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLOUDMAPPER', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GOSEC', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLAWFINDER', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEPENDENCY', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NMAP', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SONARQUBE', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BURPSUITE', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NESSUS', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NEXPOSE', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3022,
  serialized_end=3326,
)
_sym_db.RegisterEnumDescriptor(_RESULT_ANALYZER)

_RESULT_PARSER = _descriptor.EnumDescriptor(
  name='Parser',
  full_name='strobesbufs.analyzers.analyzer.Result.Parser',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOPARSER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BURP_XML_PARSER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='QUALYS_XML_PARSER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NESSUS_XML_PARSER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NEXPOSE_XML_PARSER', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POSTMAN_CONVERTER', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NMAP_XML_PARSER', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3329,
  serialized_end=3486,
)
_sym_db.RegisterEnumDescriptor(_RESULT_PARSER)


_SCANMETA = _descriptor.Descriptor(
  name='ScanMeta',
  full_name='strobesbufs.analyzers.analyzer.ScanMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='critical', full_name='strobesbufs.analyzers.analyzer.ScanMeta.critical', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='high', full_name='strobesbufs.analyzers.analyzer.ScanMeta.high', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='medium', full_name='strobesbufs.analyzers.analyzer.ScanMeta.medium', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low', full_name='strobesbufs.analyzers.analyzer.ScanMeta.low', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='info', full_name='strobesbufs.analyzers.analyzer.ScanMeta.info', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_bugs', full_name='strobesbufs.analyzers.analyzer.ScanMeta.total_bugs', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=186,
)


_SAST = _descriptor.Descriptor(
  name='SAST',
  full_name='strobesbufs.analyzers.analyzer.SAST',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_name', full_name='strobesbufs.analyzers.analyzer.SAST.file_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vulnerable_code', full_name='strobesbufs.analyzers.analyzer.SAST.vulnerable_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_line_no', full_name='strobesbufs.analyzers.analyzer.SAST.start_line_no', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_line_no', full_name='strobesbufs.analyzers.analyzer.SAST.end_line_no', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commit', full_name='strobesbufs.analyzers.analyzer.SAST.commit', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=298,
)


_DAST = _descriptor.Descriptor(
  name='DAST',
  full_name='strobesbufs.analyzers.analyzer.DAST',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uri', full_name='strobesbufs.analyzers.analyzer.DAST.uri', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='strobesbufs.analyzers.analyzer.DAST.port', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='method', full_name='strobesbufs.analyzers.analyzer.DAST.method', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='param', full_name='strobesbufs.analyzers.analyzer.DAST.param', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='evidence', full_name='strobesbufs.analyzers.analyzer.DAST.evidence', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers', full_name='strobesbufs.analyzers.analyzer.DAST.request_headers', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_headers', full_name='strobesbufs.analyzers.analyzer.DAST.response_headers', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=301,
  serialized_end=472,
)


_NETWORK = _descriptor.Descriptor(
  name='Network',
  full_name='strobesbufs.analyzers.analyzer.Network',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ipaddress', full_name='strobesbufs.analyzers.analyzer.Network.ipaddress', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='strobesbufs.analyzers.analyzer.Network.port', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='strobesbufs.analyzers.analyzer.Network.hostname', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='macaddress', full_name='strobesbufs.analyzers.analyzer.Network.macaddress', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpe', full_name='strobesbufs.analyzers.analyzer.Network.cpe', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=475,
  serialized_end=606,
)


_PACKAGE = _descriptor.Descriptor(
  name='Package',
  full_name='strobesbufs.analyzers.analyzer.Package',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='strobesbufs.analyzers.analyzer.Package.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='installed_version', full_name='strobesbufs.analyzers.analyzer.Package.installed_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='affected_versions', full_name='strobesbufs.analyzers.analyzer.Package.affected_versions', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commit', full_name='strobesbufs.analyzers.analyzer.Package.commit', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=608,
  serialized_end=701,
)


_CONTAINER = _descriptor.Descriptor(
  name='Container',
  full_name='strobesbufs.analyzers.analyzer.Container',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='package_name', full_name='strobesbufs.analyzers.analyzer.Container.package_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fixed_version', full_name='strobesbufs.analyzers.analyzer.Container.fixed_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='installed_version', full_name='strobesbufs.analyzers.analyzer.Container.installed_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpe', full_name='strobesbufs.analyzers.analyzer.Container.cpe', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='digest', full_name='strobesbufs.analyzers.analyzer.Container.digest', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=703,
  serialized_end=815,
)


_AWS = _descriptor.Descriptor(
  name='AWS',
  full_name='strobesbufs.analyzers.analyzer.AWS',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='strobesbufs.analyzers.analyzer.AWS.resource_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='strobesbufs.analyzers.analyzer.AWS.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='category', full_name='strobesbufs.analyzers.analyzer.AWS.category', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _AWS_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=818,
  serialized_end=1279,
)


_CLOUD = _descriptor.Descriptor(
  name='Cloud',
  full_name='strobesbufs.analyzers.analyzer.Cloud',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='region', full_name='strobesbufs.analyzers.analyzer.Cloud.region', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aws', full_name='strobesbufs.analyzers.analyzer.Cloud.aws', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1281,
  serialized_end=1354,
)


_PORT = _descriptor.Descriptor(
  name='Port',
  full_name='strobesbufs.analyzers.analyzer.Port',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocol', full_name='strobesbufs.analyzers.analyzer.Port.protocol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_id', full_name='strobesbufs.analyzers.analyzer.Port.port_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service', full_name='strobesbufs.analyzers.analyzer.Port.service', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='product', full_name='strobesbufs.analyzers.analyzer.Port.product', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='strobesbufs.analyzers.analyzer.Port.state', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PORT_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1357,
  serialized_end=1614,
)


_ASSET = _descriptor.Descriptor(
  name='Asset',
  full_name='strobesbufs.analyzers.analyzer.Asset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='strobesbufs.analyzers.analyzer.Asset.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipaddress', full_name='strobesbufs.analyzers.analyzer.Asset.ipaddress', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='os', full_name='strobesbufs.analyzers.analyzer.Asset.os', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mac_address', full_name='strobesbufs.analyzers.analyzer.Asset.mac_address', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='strobesbufs.analyzers.analyzer.Asset.hostname', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='netbios', full_name='strobesbufs.analyzers.analyzer.Asset.netbios', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpe', full_name='strobesbufs.analyzers.analyzer.Asset.cpe', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='strobesbufs.analyzers.analyzer.Asset.tags', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='risk_score', full_name='strobesbufs.analyzers.analyzer.Asset.risk_score', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ports', full_name='strobesbufs.analyzers.analyzer.Asset.ports', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='strobesbufs.analyzers.analyzer.Asset.state', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ASSET_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1617,
  serialized_end=1912,
)


_BUG_SCANDETAILSENTRY = _descriptor.Descriptor(
  name='ScanDetailsEntry',
  full_name='strobesbufs.analyzers.analyzer.Bug.ScanDetailsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='strobesbufs.analyzers.analyzer.Bug.ScanDetailsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='strobesbufs.analyzers.analyzer.Bug.ScanDetailsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2634,
  serialized_end=2684,
)

_BUG = _descriptor.Descriptor(
  name='Bug',
  full_name='strobesbufs.analyzers.analyzer.Bug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='strobesbufs.analyzers.analyzer.Bug.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='strobesbufs.analyzers.analyzer.Bug.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='severity', full_name='strobesbufs.analyzers.analyzer.Bug.severity', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='CVSS', full_name='strobesbufs.analyzers.analyzer.Bug.CVSS', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step_to_reproduce', full_name='strobesbufs.analyzers.analyzer.Bug.step_to_reproduce', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mitigation', full_name='strobesbufs.analyzers.analyzer.Bug.mitigation', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='CVE', full_name='strobesbufs.analyzers.analyzer.Bug.CVE', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='CWE', full_name='strobesbufs.analyzers.analyzer.Bug.CWE', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='references', full_name='strobesbufs.analyzers.analyzer.Bug.references', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sast', full_name='strobesbufs.analyzers.analyzer.Bug.sast', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dast', full_name='strobesbufs.analyzers.analyzer.Bug.dast', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network', full_name='strobesbufs.analyzers.analyzer.Bug.network', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cloud', full_name='strobesbufs.analyzers.analyzer.Bug.cloud', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='package', full_name='strobesbufs.analyzers.analyzer.Bug.package', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='container', full_name='strobesbufs.analyzers.analyzer.Bug.container', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scan_details', full_name='strobesbufs.analyzers.analyzer.Bug.scan_details', index=15,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='strobesbufs.analyzers.analyzer.Bug.tags', index=16,
      number=17, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extra_info', full_name='strobesbufs.analyzers.analyzer.Bug.extra_info', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vulnerable_since', full_name='strobesbufs.analyzers.analyzer.Bug.vulnerable_since', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='asset', full_name='strobesbufs.analyzers.analyzer.Bug.asset', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BUG_SCANDETAILSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1915,
  serialized_end=2684,
)


_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='strobesbufs.analyzers.analyzer.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scan_meta', full_name='strobesbufs.analyzers.analyzer.Result.scan_meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bugs_list', full_name='strobesbufs.analyzers.analyzer.Result.bugs_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assets_list', full_name='strobesbufs.analyzers.analyzer.Result.assets_list', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='analyzer', full_name='strobesbufs.analyzers.analyzer.Result.analyzer', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parser', full_name='strobesbufs.analyzers.analyzer.Result.parser', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success', full_name='strobesbufs.analyzers.analyzer.Result.success', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RESULT_ANALYZER,
    _RESULT_PARSER,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2687,
  serialized_end=3486,
)

_DAST.fields_by_name['port'].message_type = _PORT
_NETWORK.fields_by_name['port'].message_type = _PORT
_AWS.fields_by_name['type'].enum_type = _AWS_TYPE
_AWS_TYPE.containing_type = _AWS
_CLOUD.fields_by_name['aws'].message_type = _AWS
_PORT.fields_by_name['state'].enum_type = _PORT_STATE
_PORT_STATE.containing_type = _PORT
_ASSET.fields_by_name['ports'].message_type = _PORT
_ASSET.fields_by_name['state'].enum_type = _ASSET_STATE
_ASSET_STATE.containing_type = _ASSET
_BUG_SCANDETAILSENTRY.containing_type = _BUG
_BUG.fields_by_name['sast'].message_type = _SAST
_BUG.fields_by_name['dast'].message_type = _DAST
_BUG.fields_by_name['network'].message_type = _NETWORK
_BUG.fields_by_name['cloud'].message_type = _CLOUD
_BUG.fields_by_name['package'].message_type = _PACKAGE
_BUG.fields_by_name['container'].message_type = _CONTAINER
_BUG.fields_by_name['scan_details'].message_type = _BUG_SCANDETAILSENTRY
_BUG.fields_by_name['extra_info'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_BUG.fields_by_name['asset'].message_type = _ASSET
_RESULT.fields_by_name['scan_meta'].message_type = _SCANMETA
_RESULT.fields_by_name['bugs_list'].message_type = _BUG
_RESULT.fields_by_name['assets_list'].message_type = _ASSET
_RESULT.fields_by_name['analyzer'].enum_type = _RESULT_ANALYZER
_RESULT.fields_by_name['parser'].enum_type = _RESULT_PARSER
_RESULT_ANALYZER.containing_type = _RESULT
_RESULT_PARSER.containing_type = _RESULT
DESCRIPTOR.message_types_by_name['ScanMeta'] = _SCANMETA
DESCRIPTOR.message_types_by_name['SAST'] = _SAST
DESCRIPTOR.message_types_by_name['DAST'] = _DAST
DESCRIPTOR.message_types_by_name['Network'] = _NETWORK
DESCRIPTOR.message_types_by_name['Package'] = _PACKAGE
DESCRIPTOR.message_types_by_name['Container'] = _CONTAINER
DESCRIPTOR.message_types_by_name['AWS'] = _AWS
DESCRIPTOR.message_types_by_name['Cloud'] = _CLOUD
DESCRIPTOR.message_types_by_name['Port'] = _PORT
DESCRIPTOR.message_types_by_name['Asset'] = _ASSET
DESCRIPTOR.message_types_by_name['Bug'] = _BUG
DESCRIPTOR.message_types_by_name['Result'] = _RESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ScanMeta = _reflection.GeneratedProtocolMessageType('ScanMeta', (_message.Message,), {
  'DESCRIPTOR' : _SCANMETA,
  '__module__' : 'analyzers_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer.ScanMeta)
  })
_sym_db.RegisterMessage(ScanMeta)

SAST = _reflection.GeneratedProtocolMessageType('SAST', (_message.Message,), {
  'DESCRIPTOR' : _SAST,
  '__module__' : 'analyzers_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer.SAST)
  })
_sym_db.RegisterMessage(SAST)

DAST = _reflection.GeneratedProtocolMessageType('DAST', (_message.Message,), {
  'DESCRIPTOR' : _DAST,
  '__module__' : 'analyzers_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer.DAST)
  })
_sym_db.RegisterMessage(DAST)

Network = _reflection.GeneratedProtocolMessageType('Network', (_message.Message,), {
  'DESCRIPTOR' : _NETWORK,
  '__module__' : 'analyzers_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer.Network)
  })
_sym_db.RegisterMessage(Network)

Package = _reflection.GeneratedProtocolMessageType('Package', (_message.Message,), {
  'DESCRIPTOR' : _PACKAGE,
  '__module__' : 'analyzers_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer.Package)
  })
_sym_db.RegisterMessage(Package)

Container = _reflection.GeneratedProtocolMessageType('Container', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINER,
  '__module__' : 'analyzers_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer.Container)
  })
_sym_db.RegisterMessage(Container)

AWS = _reflection.GeneratedProtocolMessageType('AWS', (_message.Message,), {
  'DESCRIPTOR' : _AWS,
  '__module__' : 'analyzers_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer.AWS)
  })
_sym_db.RegisterMessage(AWS)

Cloud = _reflection.GeneratedProtocolMessageType('Cloud', (_message.Message,), {
  'DESCRIPTOR' : _CLOUD,
  '__module__' : 'analyzers_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer.Cloud)
  })
_sym_db.RegisterMessage(Cloud)

Port = _reflection.GeneratedProtocolMessageType('Port', (_message.Message,), {
  'DESCRIPTOR' : _PORT,
  '__module__' : 'analyzers_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer.Port)
  })
_sym_db.RegisterMessage(Port)

Asset = _reflection.GeneratedProtocolMessageType('Asset', (_message.Message,), {
  'DESCRIPTOR' : _ASSET,
  '__module__' : 'analyzers_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer.Asset)
  })
_sym_db.RegisterMessage(Asset)

Bug = _reflection.GeneratedProtocolMessageType('Bug', (_message.Message,), {

  'ScanDetailsEntry' : _reflection.GeneratedProtocolMessageType('ScanDetailsEntry', (_message.Message,), {
    'DESCRIPTOR' : _BUG_SCANDETAILSENTRY,
    '__module__' : 'analyzers_pb2'
    # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer.Bug.ScanDetailsEntry)
    })
  ,
  'DESCRIPTOR' : _BUG,
  '__module__' : 'analyzers_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer.Bug)
  })
_sym_db.RegisterMessage(Bug)
_sym_db.RegisterMessage(Bug.ScanDetailsEntry)

Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'analyzers_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer.Result)
  })
_sym_db.RegisterMessage(Result)


_BUG_SCANDETAILSENTRY._options = None
# @@protoc_insertion_point(module_scope)
